SNCosmo
=======

_Python library for supernova cosmology_

[![Build Status](https://img.shields.io/travis/sncosmo/sncosmo.svg?style=flat-square&label=linux)](https://travis-ci.org/sncosmo/sncosmo)
[![Build status](https://img.shields.io/appveyor/ci/kbarbary/sncosmo.svg?style=flat-square&label=windows)](https://ci.appveyor.com/project/kbarbary/sncosmo/branch/master)
[![Coverage Status](http://img.shields.io/coveralls/sncosmo/sncosmo.svg?style=flat-square)](https://coveralls.io/r/sncosmo/sncosmo?branch=master)
[![PyPI](https://img.shields.io/pypi/v/sncosmo.svg?style=flat-square)](https://pypi.python.org/pypi/sncosmo)

**Documentation:** http://sncosmo.readthedocs.io

**Mailing list:** https://groups.google.com/forum/#!forum/sncosmo

**Citing sncosmo:** [![DOI](http://img.shields.io/badge/DOI-10.5281%2Fzenodo.11938-blue.svg?style=flat-square)](http://dx.doi.org/10.5281/zenodo.11938)
